Package: visreg
Title: Visualization of Regression Models
Version: 2.8.0
Authors@R: c(
  person("Patrick", "Breheny", role=c("aut","cre"),
         email="patrick-breheny@uiowa.edu",
         comment=c(ORCID="0000-0002-0650-1119")),
  person("Woodrow", "Burchett", role=c("ctb")))
Description: Provides a convenient interface for constructing plots to
    visualize the fit of regression models arising from a wide variety
    of models in R ('lm', 'glm', 'coxph', 'rlm', 'gam', 'locfit', 'lmer',
    'randomForest', etc.)
License: GPL-3
URL: https://pbreheny.github.io/visreg/,
        https://github.com/pbreheny/visreg
BugReports: https://github.com/pbreheny/visreg/issues
Depends: R (>= 4.1)
Imports: lattice
Suggests: ggplot2, glmmTMB, knitr, lme4, MASS, Matrix, rgl, rmarkdown,
        survival, tinytest
Enhances: nlme
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-08-05 03:10:23 UTC; pbreheny
Author: Patrick Breheny [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0650-1119>),
  Woodrow Burchett [ctb]
Maintainer: Patrick Breheny <patrick-breheny@uiowa.edu>
Repository: CRAN
Date/Publication: 2025-08-20 15:00:02 UTC
Built: R 4.6.0; ; 2026-04-25 23:04:42 UTC; unix
