# Generated by roxygen2: do not edit by hand

S3method(plot,visreg)
S3method(plot,visreg2d)
S3method(plot,visregList)
S3method(subset,visreg)
export(visreg)
export(visreg2d)
export(visregList)
import(grDevices)
import(graphics)
import(stats)
import(utils)
