airquality$Heat <- cut(airquality$Temp,3,labels=c("Cool","Mild","Hot"))
fit <- lm(Ozone~ Solar.R + Wind*Heat,data=airquality)
v <- visreg(fit, "Wind", by="Heat", plot=FALSE)
vv <- subset(v, Heat %in% c("Cool", "Hot"))
plot(vv)
vv <- subset(v, Wind < 15)
plot(vv)
